==> blesta-5.10.2.zip: blesta/plugins/download_manager/language/de_de/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.package_name'] = '%1$s (%2$s)';
$lang['AdminMain.editcategory.submit_cancel'] = 'Abbrechen';
$lang['AdminMain.editcategory.submit_edit'] = 'Kategorie aktualisieren';
$lang['AdminMain.editcategory.field_description'] = 'Beschreibung';
$lang['AdminMain.editcategory.field_name'] = 'Name';
$lang['AdminMain.editcategory.boxtitle_editcategory'] = 'Kategorie aktualisieren [%1$s]';
$lang['AdminMain.editcategory.page_title'] = 'Download Manager > Kategorie aktualisieren';
$lang['AdminMain.addcategory.submit_cancel'] = 'Abbrechen';
$lang['AdminMain.addcategory.submit_add'] = 'Kategorie erstellen';
$lang['AdminMain.addcategory.field_description'] = 'Beschreibung';
$lang['AdminMain.addcategory.field_name'] = 'Name';
$lang['AdminMain.addcategory.boxtitle_addcategory'] = 'Kategorie zur Kategorie [%1$s] hinzufügen';
$lang['AdminMain.addcategory.boxtitle_root'] = 'Kategorie zu den %1$s hinzufügen';
$lang['AdminMain.addcategory.page_title'] = 'Download Manager > Kategorie hinzufügen';
$lang['AdminMain.editurl.submit_cancel'] = 'Abbrechen';
$lang['AdminMain.editurl.submit_add'] = 'URL bearbeiten';
$lang['AdminMain.editurl.field_category'] = 'Kategorie';
$lang['AdminMain.editurl.field_file'] = 'Datei';
$lang['AdminMain.editurl.field_url'] = 'URL Name';
$lang['AdminMain.editurl.boxtitle_add'] = 'Statische URL bearbeiten';
$lang['AdminMain.editurl.page_title'] = 'Download Manager > Statische URL bearbeiten';
$lang['AdminMain.edit.submit_cancel'] = 'Abbrechen';
$lang['AdminMain.edit.submit_edit'] = 'Update Download';
$lang['AdminMain.edit.field_file_name'] = 'Pfad zur Datei';
$lang['AdminMain.edit.field_file'] = 'Datei';
$lang['AdminMain.edit.field_path'] = 'Pfad zur Datei angeben';
$lang['AdminMain.edit.field_upload'] = 'Datei hochladen';
$lang['AdminMain.edit.text_availablepackages'] = 'Verfügbare Pakete';
$lang['AdminMain.edit.text_availableclientgroups'] = 'Verfügbare Kundengruppen';
$lang['AdminMain.edit.text_packagegroups'] = 'Ausgewählte Pakete';
$lang['AdminMain.edit.text_clientgroups'] = 'Ausgewählte Kundengruppen';
$lang['AdminMain.edit.field_available_to_packages'] = 'Verfügbar für Pakete';
$lang['AdminMain.edit.field_available_to_client_groups'] = 'Verfügbar für Kundengruppen';
$lang['AdminMain.edit.field_name'] = 'Name';
$lang['AdminMain.edit.field_logged_in'] = 'Muss eingeloggt sein';
$lang['AdminMain.edit.field_public'] = 'Öffentlich zugänglich';
$lang['AdminMain.edit.boxtitle_edit'] = 'Update Download';
$lang['AdminMain.edit.page_title'] = 'Download Manager > Download hinzufügen';
$lang['AdminMain.addurl.submit_cancel'] = 'Abbrechen';
$lang['AdminMain.addurl.submit_add'] = 'URL hinzufügen';
$lang['AdminMain.addurl.field_category'] = 'Kategorie';
$lang['AdminMain.addurl.field_file'] = 'Datei';
$lang['AdminMain.addurl.field_url'] = 'URL Name';
$lang['AdminMain.addurl.boxtitle_add'] = 'Statische URL hinzufügen';
$lang['AdminMain.addurl.page_title'] = 'Download Manager > Statische URL hinzufügen';
$lang['AdminMain.add.submit_cancel'] = 'Abbrechen';
$lang['AdminMain.add.submit_add'] = 'Download hinzufügen';
$lang['AdminMain.add.field_file_name'] = 'Pfad zur Datei';
$lang['AdminMain.add.field_file'] = 'Datei';
$lang['AdminMain.add.field_path'] = 'Pfad zur Datei angeben';
$lang['AdminMain.add.field_upload'] = 'Datei hochladen';
$lang['AdminMain.add.text_availablepackages'] = 'Verfügbare Pakete';
$lang['AdminMain.add.text_availableclientgroups'] = 'Verfügbare Kundengruppen';
$lang['AdminMain.add.text_packagegroups'] = 'Ausgewählte Pakete';
$lang['AdminMain.add.text_clientgroups'] = 'Ausgewählte Kundengruppen';
$lang['AdminMain.add.field_available_to_packages'] = 'Verfügbar für Pakete';
$lang['AdminMain.add.field_available_to_client_groups'] = 'Verfügbar für Kundengruppen';
$lang['AdminMain.add.field_name'] = 'Name';
$lang['AdminMain.add.field_logged_in'] = 'Muss eingeloggt sein';
$lang['AdminMain.add.field_public'] = 'Öffentlich zugänglich';
$lang['AdminMain.add.boxtitle_add'] = 'Download zur Kategorie [%1$s] hinzufügen';
$lang['AdminMain.add.boxtitle_root'] = 'Download zu den %1$s hinzufügen';
$lang['AdminMain.add.page_title'] = 'Download Manager > Download hinzufügen';
$lang['AdminMain.urls.no_urls'] = 'In diesem Abschnitt gibt es keine statischen URLs.';
$lang['AdminMain.urls.latest_file'] = 'Neueste Datei von <strong>%1$s</strong>';
$lang['AdminMain.urls.delete'] = 'Löschen';
$lang['AdminMain.urls.edit'] = 'bearbeiten';
$lang['AdminMain.urls.heading_options'] = 'Optionen';
$lang['AdminMain.urls.heading_link'] = 'Link';
$lang['AdminMain.urls.heading_file'] = 'Datei';
$lang['AdminMain.urls.heading_url'] = 'URL';
$lang['AdminMain.urls.tab_urls'] = 'Statische URLs';
$lang['AdminMain.urls.tab_files'] = 'Dateien';
$lang['AdminMain.urls.add_url'] = 'Statische URL hinzufügen';
$lang['AdminMain.urls.boxtitle_downloadmanager'] = 'Manager herunterladen';
$lang['AdminMain.urls.page_title'] = 'Download Manager > Verwalten';
$lang['AdminMain.files.no_downloads'] = 'In diesem Bereich gibt es keine Downloads.';
$lang['AdminMain.files.delete'] = 'Löschen';
$lang['AdminMain.files.edit'] = 'bearbeiten';
$lang['AdminMain.files.go_back'] = 'Eine Ebene höher gehen';
$lang['AdminMain.files.add_category'] = 'Hier Kategorie hinzufügen';
$lang['AdminMain.files.add_download'] = 'Download hier hinzufügen';
$lang['AdminMain.files.tab_urls'] = 'Statische URLs';
$lang['AdminMain.files.tab_files'] = 'Dateien';
$lang['AdminMain.files.boxtitle_downloadmanager'] = 'Manager herunterladen';
$lang['AdminMain.files.page_title'] = 'Download Manager > Verwalten';
$lang['AdminMain.modal.delete_url'] = 'Sind Sie sicher, dass Sie diese statische URL löschen wollen?';
$lang['AdminMain.modal.delete_category'] = 'Sind Sie sicher, dass Sie diese Kategorie löschen möchten? Alle Unterkategorien und Dateien innerhalb dieser Kategorie werden in die übergeordnete Kategorie verschoben.';
$lang['AdminMain.modal.delete_file'] = 'Sind Sie sicher, dass Sie diese Datei löschen wollen?';
$lang['AdminMain.!text.closed_parenthesis'] = ')';
$lang['AdminMain.!text.forward_slash'] = '/';
$lang['AdminMain.!text.open_parenthesis'] = '(';
$lang['AdminMain.!text.root_directory'] = 'Home-Verzeichnis';
$lang['AdminMain.!tooltip.category_type'] = 'Die URL verweist auf die zuletzt in diese Kategorie hochgeladene Datei.';
$lang['AdminMain.!tooltip.path_to_file'] = 'Geben Sie den absoluten Pfad zu der Datei im Dateisystem an.';
$lang['AdminMain.!success.url_updated'] = 'Die statische URL wurde erfolgreich aktualisiert.';
$lang['AdminMain.!success.url_added'] = 'Die statische URL wurde erfolgreich hinzugefügt.';
$lang['AdminMain.!success.url_deleted'] = 'Die statische URL wurde erfolgreich gelöscht.';
$lang['AdminMain.!success.file_deleted'] = 'Die Datei wurde erfolgreich gelöscht.';
$lang['AdminMain.!success.file_updated'] = 'Die Datei wurde erfolgreich aktualisiert.';
$lang['AdminMain.!success.file_added'] = 'Die Datei wurde erfolgreich hinzugefügt.';
$lang['AdminMain.!success.category_deleted'] = 'Die Kategorie wurde erfolgreich gelöscht.';
$lang['AdminMain.!success.category_updated'] = 'Die Kategorie wurde erfolgreich aktualisiert.';
$lang['AdminMain.!success.category_added'] = 'Die Kategorie wurde erfolgreich erstellt.';

==> blesta-5.11.4.zip: blesta/plugins/download_manager/language/de_de/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.package_name'] = '%1$s (%2$s)';
$lang['AdminMain.editcategory.submit_cancel'] = 'Abbrechen';
$lang['AdminMain.editcategory.submit_edit'] = 'Kategorie aktualisieren';
$lang['AdminMain.editcategory.field_description'] = 'Beschreibung';
$lang['AdminMain.editcategory.field_name'] = 'Name';
$lang['AdminMain.editcategory.boxtitle_editcategory'] = 'Kategorie aktualisieren [%1$s]';
$lang['AdminMain.editcategory.page_title'] = 'Download Manager > Kategorie aktualisieren';
$lang['AdminMain.addcategory.submit_cancel'] = 'Abbrechen';
$lang['AdminMain.addcategory.submit_add'] = 'Kategorie erstellen';
$lang['AdminMain.addcategory.field_description'] = 'Beschreibung';
$lang['AdminMain.addcategory.field_name'] = 'Name';
$lang['AdminMain.addcategory.boxtitle_addcategory'] = 'Kategorie zur Kategorie [%1$s] hinzufügen';
$lang['AdminMain.addcategory.boxtitle_root'] = 'Kategorie zu den %1$s hinzufügen';
$lang['AdminMain.addcategory.page_title'] = 'Download Manager > Kategorie hinzufügen';
$lang['AdminMain.editurl.submit_cancel'] = 'Abbrechen';
$lang['AdminMain.editurl.submit_add'] = 'URL bearbeiten';
$lang['AdminMain.editurl.field_category'] = 'Kategorie';
$lang['AdminMain.editurl.field_file'] = 'Datei';
$lang['AdminMain.editurl.field_url'] = 'URL Name';
$lang['AdminMain.editurl.boxtitle_add'] = 'Statische URL bearbeiten';
$lang['AdminMain.editurl.page_title'] = 'Download Manager > Statische URL bearbeiten';
$lang['AdminMain.edit.submit_cancel'] = 'Abbrechen';
$lang['AdminMain.edit.submit_edit'] = 'Update Download';
$lang['AdminMain.edit.field_file_name'] = 'Pfad zur Datei';
$lang['AdminMain.edit.field_file'] = 'Datei';
$lang['AdminMain.edit.field_path'] = 'Pfad zur Datei angeben';
$lang['AdminMain.edit.field_upload'] = 'Datei hochladen';
$lang['AdminMain.edit.text_availablepackages'] = 'Verfügbare Pakete';
$lang['AdminMain.edit.text_availableclientgroups'] = 'Verfügbare Kundengruppen';
$lang['AdminMain.edit.text_packagegroups'] = 'Ausgewählte Pakete';
$lang['AdminMain.edit.text_clientgroups'] = 'Ausgewählte Kundengruppen';
$lang['AdminMain.edit.field_available_to_packages'] = 'Verfügbar für Pakete';
$lang['AdminMain.edit.field_available_to_client_groups'] = 'Verfügbar für Kundengruppen';
$lang['AdminMain.edit.field_name'] = 'Name';
$lang['AdminMain.edit.field_logged_in'] = 'Muss eingeloggt sein';
$lang['AdminMain.edit.field_public'] = 'Öffentlich zugänglich';
$lang['AdminMain.edit.boxtitle_edit'] = 'Update Download';
$lang['AdminMain.edit.page_title'] = 'Download Manager > Download hinzufügen';
$lang['AdminMain.addurl.submit_cancel'] = 'Abbrechen';
$lang['AdminMain.addurl.submit_add'] = 'URL hinzufügen';
$lang['AdminMain.addurl.field_category'] = 'Kategorie';
$lang['AdminMain.addurl.field_file'] = 'Datei';
$lang['AdminMain.addurl.field_url'] = 'URL Name';
$lang['AdminMain.addurl.boxtitle_add'] = 'Statische URL hinzufügen';
$lang['AdminMain.addurl.page_title'] = 'Download Manager > Statische URL hinzufügen';
$lang['AdminMain.add.submit_cancel'] = 'Abbrechen';
$lang['AdminMain.add.submit_add'] = 'Download hinzufügen';
$lang['AdminMain.add.field_file_name'] = 'Pfad zur Datei';
$lang['AdminMain.add.field_file'] = 'Datei';
$lang['AdminMain.add.field_path'] = 'Pfad zur Datei angeben';
$lang['AdminMain.add.field_upload'] = 'Datei hochladen';
$lang['AdminMain.add.text_availablepackages'] = 'Verfügbare Pakete';
$lang['AdminMain.add.text_availableclientgroups'] = 'Verfügbare Kundengruppen';
$lang['AdminMain.add.text_packagegroups'] = 'Ausgewählte Pakete';
$lang['AdminMain.add.text_clientgroups'] = 'Ausgewählte Kundengruppen';
$lang['AdminMain.add.field_available_to_packages'] = 'Verfügbar für Pakete';
$lang['AdminMain.add.field_available_to_client_groups'] = 'Verfügbar für Kundengruppen';
$lang['AdminMain.add.field_name'] = 'Name';
$lang['AdminMain.add.field_logged_in'] = 'Muss eingeloggt sein';
$lang['AdminMain.add.field_public'] = 'Öffentlich zugänglich';
$lang['AdminMain.add.boxtitle_add'] = 'Download zur Kategorie [%1$s] hinzufügen';
$lang['AdminMain.add.boxtitle_root'] = 'Download zu den %1$s hinzufügen';
$lang['AdminMain.add.page_title'] = 'Download Manager > Download hinzufügen';
$lang['AdminMain.urls.no_urls'] = 'In diesem Abschnitt gibt es keine statischen URLs.';
$lang['AdminMain.urls.latest_file'] = 'Neueste Datei von <strong>%1$s</strong>';
$lang['AdminMain.urls.delete'] = 'Löschen';
$lang['AdminMain.urls.edit'] = 'bearbeiten';
$lang['AdminMain.urls.heading_options'] = 'Optionen';
$lang['AdminMain.urls.heading_link'] = 'Link';
$lang['AdminMain.urls.heading_file'] = 'Datei';
$lang['AdminMain.urls.heading_url'] = 'URL';
$lang['AdminMain.urls.tab_urls'] = 'Statische URLs';
$lang['AdminMain.urls.tab_files'] = 'Dateien';
$lang['AdminMain.urls.add_url'] = 'Statische URL hinzufügen';
$lang['AdminMain.urls.boxtitle_downloadmanager'] = 'Manager herunterladen';
$lang['AdminMain.urls.page_title'] = 'Download Manager > Verwalten';
$lang['AdminMain.files.no_downloads'] = 'In diesem Bereich gibt es keine Downloads.';
$lang['AdminMain.files.delete'] = 'Löschen';
$lang['AdminMain.files.edit'] = 'bearbeiten';
$lang['AdminMain.files.go_back'] = 'Eine Ebene höher gehen';
$lang['AdminMain.files.add_category'] = 'Hier Kategorie hinzufügen';
$lang['AdminMain.files.add_download'] = 'Download hier hinzufügen';
$lang['AdminMain.files.tab_urls'] = 'Statische URLs';
$lang['AdminMain.files.tab_files'] = 'Dateien';
$lang['AdminMain.files.boxtitle_downloadmanager'] = 'Manager herunterladen';
$lang['AdminMain.files.page_title'] = 'Download Manager > Verwalten';
$lang['AdminMain.modal.delete_url'] = 'Sind Sie sicher, dass Sie diese statische URL löschen wollen?';
$lang['AdminMain.modal.delete_category'] = 'Sind Sie sicher, dass Sie diese Kategorie löschen möchten? Alle Unterkategorien und Dateien innerhalb dieser Kategorie werden in die übergeordnete Kategorie verschoben.';
$lang['AdminMain.modal.delete_file'] = 'Sind Sie sicher, dass Sie diese Datei löschen wollen?';
$lang['AdminMain.!text.closed_parenthesis'] = ')';
$lang['AdminMain.!text.forward_slash'] = '/';
$lang['AdminMain.!text.open_parenthesis'] = '(';
$lang['AdminMain.!text.root_directory'] = 'Home-Verzeichnis';
$lang['AdminMain.!tooltip.category_type'] = 'Die URL verweist auf die zuletzt in diese Kategorie hochgeladene Datei.';
$lang['AdminMain.!tooltip.path_to_file'] = 'Geben Sie den absoluten Pfad zu der Datei im Dateisystem an.';
$lang['AdminMain.!success.url_updated'] = 'Die statische URL wurde erfolgreich aktualisiert.';
$lang['AdminMain.!success.url_added'] = 'Die statische URL wurde erfolgreich hinzugefügt.';
$lang['AdminMain.!success.url_deleted'] = 'Die statische URL wurde erfolgreich gelöscht.';
$lang['AdminMain.!success.file_deleted'] = 'Die Datei wurde erfolgreich gelöscht.';
$lang['AdminMain.!success.file_updated'] = 'Die Datei wurde erfolgreich aktualisiert.';
$lang['AdminMain.!success.file_added'] = 'Die Datei wurde erfolgreich hinzugefügt.';
$lang['AdminMain.!success.category_deleted'] = 'Die Kategorie wurde erfolgreich gelöscht.';
$lang['AdminMain.!success.category_updated'] = 'Die Kategorie wurde erfolgreich aktualisiert.';
$lang['AdminMain.!success.category_added'] = 'Die Kategorie wurde erfolgreich erstellt.';
$lang['AdminMain.edit.text_full_path'] = 'HINWEIS: Die Dateien müssen sich irgendwo in Ihrem Uploads-Verzeichnis befinden: <strong>%1$s</strong>.';
$lang['AdminMain.add.text_full_path'] = 'HINWEIS: Die Dateien müssen sich irgendwo in Ihrem Uploads-Verzeichnis befinden: <strong>%1$s</strong>.';
